Class: Wire4Client::Deposit
- Inherits:
-
Object
- Object
- Wire4Client::Deposit
- Defined in:
- lib/wire4_client/models/deposit.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
Monto de la transferencia.
-
#beneficiary_account ⇒ Object
La cuenta del beneficiario.
-
#beneficiary_name ⇒ Object
El nombre del beneficiario.
-
#beneficiary_rfc ⇒ Object
El RFC del beneficiario.
-
#cep ⇒ Object
CEP emitido por Banxico de la transferencia, sólo en caso de que este disponible en banxico, posteriomente podrá usar la consulta de CEP del API.
-
#clave_rastreo ⇒ Object
La clave de rastreo de la transferencia.
-
#confirm_date ⇒ Object
Fecha de confirmación del deposito.
-
#currency_code ⇒ Object
Código de moneda de la transferencia.
-
#deposit_date ⇒ Object
Fecha del deposito.
-
#depositant ⇒ Object
Depositante.
-
#depositant_clabe ⇒ Object
Cuenta CLABE interbancaria del depositante.
-
#depositant_email ⇒ Object
Email del depositante.
-
#depositant_rfc ⇒ Object
RFC del depositante.
-
#description ⇒ Object
Descripción del traspaso.
-
#monex_description ⇒ Object
Descripción directa de Monex.
-
#monex_transaction_id ⇒ Object
Identificador de la transferencia en Monex.
-
#reference ⇒ Object
La referencia del depósito.
-
#sender_account ⇒ Object
La cuenta del ordenante.
-
#sender_bank ⇒ Object
El banco del ordenante.
-
#sender_name ⇒ Object
El nombre del ordenante.
-
#sender_rfc ⇒ Object
El RFC del ordenante.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Deposit
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ Deposit
Initializes the object
136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 |
# File 'lib/wire4_client/models/deposit.rb', line 136 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } if attributes.has_key?(:'amount') self.amount = attributes[:'amount'] end if attributes.has_key?(:'beneficiary_account') self.beneficiary_account = attributes[:'beneficiary_account'] end if attributes.has_key?(:'beneficiary_name') self.beneficiary_name = attributes[:'beneficiary_name'] end if attributes.has_key?(:'beneficiary_rfc') self.beneficiary_rfc = attributes[:'beneficiary_rfc'] end if attributes.has_key?(:'cep') self.cep = attributes[:'cep'] end if attributes.has_key?(:'clave_rastreo') self.clave_rastreo = attributes[:'clave_rastreo'] end if attributes.has_key?(:'confirm_date') self.confirm_date = attributes[:'confirm_date'] end if attributes.has_key?(:'currency_code') self.currency_code = attributes[:'currency_code'] end if attributes.has_key?(:'deposit_date') self.deposit_date = attributes[:'deposit_date'] end if attributes.has_key?(:'depositant') self.depositant = attributes[:'depositant'] end if attributes.has_key?(:'depositant_clabe') self.depositant_clabe = attributes[:'depositant_clabe'] end if attributes.has_key?(:'depositant_email') self.depositant_email = attributes[:'depositant_email'] end if attributes.has_key?(:'depositant_rfc') self.depositant_rfc = attributes[:'depositant_rfc'] end if attributes.has_key?(:'description') self.description = attributes[:'description'] end if attributes.has_key?(:'monex_description') self.monex_description = attributes[:'monex_description'] end if attributes.has_key?(:'monex_transaction_id') self.monex_transaction_id = attributes[:'monex_transaction_id'] end if attributes.has_key?(:'reference') self.reference = attributes[:'reference'] end if attributes.has_key?(:'sender_account') self.sender_account = attributes[:'sender_account'] end if attributes.has_key?(:'sender_bank') self.sender_bank = attributes[:'sender_bank'] end if attributes.has_key?(:'sender_name') self.sender_name = attributes[:'sender_name'] end if attributes.has_key?(:'sender_rfc') self.sender_rfc = attributes[:'sender_rfc'] end end |
Instance Attribute Details
#amount ⇒ Object
Monto de la transferencia
18 19 20 |
# File 'lib/wire4_client/models/deposit.rb', line 18 def amount @amount end |
#beneficiary_account ⇒ Object
La cuenta del beneficiario
21 22 23 |
# File 'lib/wire4_client/models/deposit.rb', line 21 def beneficiary_account @beneficiary_account end |
#beneficiary_name ⇒ Object
El nombre del beneficiario
24 25 26 |
# File 'lib/wire4_client/models/deposit.rb', line 24 def beneficiary_name @beneficiary_name end |
#beneficiary_rfc ⇒ Object
El RFC del beneficiario
27 28 29 |
# File 'lib/wire4_client/models/deposit.rb', line 27 def beneficiary_rfc @beneficiary_rfc end |
#cep ⇒ Object
CEP emitido por Banxico de la transferencia, sólo en caso de que este disponible en banxico, posteriomente podrá usar la consulta de CEP del API
30 31 32 |
# File 'lib/wire4_client/models/deposit.rb', line 30 def cep @cep end |
#clave_rastreo ⇒ Object
La clave de rastreo de la transferencia
33 34 35 |
# File 'lib/wire4_client/models/deposit.rb', line 33 def clave_rastreo @clave_rastreo end |
#confirm_date ⇒ Object
Fecha de confirmación del deposito
36 37 38 |
# File 'lib/wire4_client/models/deposit.rb', line 36 def confirm_date @confirm_date end |
#currency_code ⇒ Object
Código de moneda de la transferencia
39 40 41 |
# File 'lib/wire4_client/models/deposit.rb', line 39 def currency_code @currency_code end |
#deposit_date ⇒ Object
Fecha del deposito
42 43 44 |
# File 'lib/wire4_client/models/deposit.rb', line 42 def deposit_date @deposit_date end |
#depositant ⇒ Object
Depositante
45 46 47 |
# File 'lib/wire4_client/models/deposit.rb', line 45 def depositant @depositant end |
#depositant_clabe ⇒ Object
Cuenta CLABE interbancaria del depositante
48 49 50 |
# File 'lib/wire4_client/models/deposit.rb', line 48 def depositant_clabe @depositant_clabe end |
#depositant_email ⇒ Object
Email del depositante
51 52 53 |
# File 'lib/wire4_client/models/deposit.rb', line 51 def depositant_email @depositant_email end |
#depositant_rfc ⇒ Object
RFC del depositante
54 55 56 |
# File 'lib/wire4_client/models/deposit.rb', line 54 def depositant_rfc @depositant_rfc end |
#description ⇒ Object
Descripción del traspaso
57 58 59 |
# File 'lib/wire4_client/models/deposit.rb', line 57 def description @description end |
#monex_description ⇒ Object
Descripción directa de Monex
60 61 62 |
# File 'lib/wire4_client/models/deposit.rb', line 60 def monex_description @monex_description end |
#monex_transaction_id ⇒ Object
Identificador de la transferencia en Monex
63 64 65 |
# File 'lib/wire4_client/models/deposit.rb', line 63 def monex_transaction_id @monex_transaction_id end |
#reference ⇒ Object
La referencia del depósito
66 67 68 |
# File 'lib/wire4_client/models/deposit.rb', line 66 def reference @reference end |
#sender_account ⇒ Object
La cuenta del ordenante
69 70 71 |
# File 'lib/wire4_client/models/deposit.rb', line 69 def sender_account @sender_account end |
#sender_bank ⇒ Object
El banco del ordenante
72 73 74 |
# File 'lib/wire4_client/models/deposit.rb', line 72 def sender_bank @sender_bank end |
#sender_name ⇒ Object
El nombre del ordenante
75 76 77 |
# File 'lib/wire4_client/models/deposit.rb', line 75 def sender_name @sender_name end |
#sender_rfc ⇒ Object
El RFC del ordenante
78 79 80 |
# File 'lib/wire4_client/models/deposit.rb', line 78 def sender_rfc @sender_rfc end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 |
# File 'lib/wire4_client/models/deposit.rb', line 81 def self.attribute_map { :'amount' => :'amount', :'beneficiary_account' => :'beneficiary_account', :'beneficiary_name' => :'beneficiary_name', :'beneficiary_rfc' => :'beneficiary_rfc', :'cep' => :'cep', :'clave_rastreo' => :'clave_rastreo', :'confirm_date' => :'confirm_date', :'currency_code' => :'currency_code', :'deposit_date' => :'deposit_date', :'depositant' => :'depositant', :'depositant_clabe' => :'depositant_clabe', :'depositant_email' => :'depositant_email', :'depositant_rfc' => :'depositant_rfc', :'description' => :'description', :'monex_description' => :'monex_description', :'monex_transaction_id' => :'monex_transaction_id', :'reference' => :'reference', :'sender_account' => :'sender_account', :'sender_bank' => :'sender_bank', :'sender_name' => :'sender_name', :'sender_rfc' => :'sender_rfc' } end |
.swagger_types ⇒ Object
Attribute type mapping.
108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 |
# File 'lib/wire4_client/models/deposit.rb', line 108 def self.swagger_types { :'amount' => :'Float', :'beneficiary_account' => :'String', :'beneficiary_name' => :'String', :'beneficiary_rfc' => :'String', :'cep' => :'MessageCEP', :'clave_rastreo' => :'String', :'confirm_date' => :'DateTime', :'currency_code' => :'String', :'deposit_date' => :'DateTime', :'depositant' => :'String', :'depositant_clabe' => :'String', :'depositant_email' => :'String', :'depositant_rfc' => :'String', :'description' => :'String', :'monex_description' => :'String', :'monex_transaction_id' => :'String', :'reference' => :'String', :'sender_account' => :'String', :'sender_bank' => :'MessageInstitution', :'sender_name' => :'String', :'sender_rfc' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 |
# File 'lib/wire4_client/models/deposit.rb', line 242 def ==(o) return true if self.equal?(o) self.class == o.class && amount == o.amount && beneficiary_account == o.beneficiary_account && beneficiary_name == o.beneficiary_name && beneficiary_rfc == o.beneficiary_rfc && cep == o.cep && clave_rastreo == o.clave_rastreo && confirm_date == o.confirm_date && currency_code == o.currency_code && deposit_date == o.deposit_date && depositant == o.depositant && depositant_clabe == o.depositant_clabe && depositant_email == o.depositant_email && depositant_rfc == o.depositant_rfc && description == o.description && monex_description == o.monex_description && monex_transaction_id == o.monex_transaction_id && reference == o.reference && sender_account == o.sender_account && sender_bank == o.sender_bank && sender_name == o.sender_name && sender_rfc == o.sender_rfc end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 |
# File 'lib/wire4_client/models/deposit.rb', line 304 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :BOOLEAN if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model temp_model = Wire4Client.const_get(type).new temp_model.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
370 371 372 373 374 375 376 377 378 379 380 381 382 |
# File 'lib/wire4_client/models/deposit.rb', line 370 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 |
# File 'lib/wire4_client/models/deposit.rb', line 283 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
270 271 272 |
# File 'lib/wire4_client/models/deposit.rb', line 270 def eql?(o) self == o end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
276 277 278 |
# File 'lib/wire4_client/models/deposit.rb', line 276 def hash [amount, beneficiary_account, beneficiary_name, beneficiary_rfc, cep, clave_rastreo, confirm_date, currency_code, deposit_date, depositant, depositant_clabe, depositant_email, depositant_rfc, description, monex_description, monex_transaction_id, reference, sender_account, sender_bank, sender_name, sender_rfc].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
229 230 231 232 |
# File 'lib/wire4_client/models/deposit.rb', line 229 def list_invalid_properties invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
350 351 352 |
# File 'lib/wire4_client/models/deposit.rb', line 350 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
356 357 358 359 360 361 362 363 364 |
# File 'lib/wire4_client/models/deposit.rb', line 356 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
344 345 346 |
# File 'lib/wire4_client/models/deposit.rb', line 344 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
236 237 238 |
# File 'lib/wire4_client/models/deposit.rb', line 236 def valid? true end |