Class: Wire4Client::MessagePayment
- Inherits:
-
Object
- Object
- Wire4Client::MessagePayment
- Defined in:
- lib/wire4_client/models/message_payment.rb
Overview
El mensaje que se envía mediante (webHook) con la información de la transferencia de salida realizada
Instance Attribute Summary collapse
-
#account ⇒ Object
Cuenta del ordenante.
-
#amount ⇒ Object
Monto de la transferencia.
-
#beneficiary_account ⇒ Object
Cuenta del beneficiario.
-
#beneficiary_bank ⇒ Object
Banco del beneficiario.
-
#beneficiary_name ⇒ Object
Nombre del beneficiario.
-
#cep ⇒ Object
Informacion del CEP.
-
#clave_rastreo ⇒ Object
Clave de rastreo de la transferencia.
-
#concept ⇒ Object
Concepto de la transferencia de salida.
-
#confirm_date ⇒ Object
Fecha de confirmación de la transferencia de salida.
-
#currency_code ⇒ Object
Código de la moneda de la transferencia de salida.
-
#detention_message ⇒ Object
Mensaje de detención de Monex de la transferencia de salida.
-
#error_message ⇒ Object
Mensaje de error.
-
#monex_description ⇒ Object
La descripción de Monex de la transferencia de salida.
-
#order_id ⇒ Object
El identificador de la transferencia de salida.
-
#payment_order_id ⇒ Object
El identificador de la orden de pago de Monex de la transferencia de salida.
-
#pending_reason ⇒ Object
Razón de porque está pendiente aún cuando se autorizó la transferencia.
-
#reference ⇒ Object
Referecia de la transferencia.
-
#request_id ⇒ Object
El identificador, en esta API, de la petición de envío de la transferencia de salida.
-
#status_code ⇒ Object
El estado de la transferencia de salida.
-
#transaction_id ⇒ Object
El identificador de Monex de la transferencia de salida.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ MessagePayment
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ MessagePayment
Initializes the object
132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 |
# File 'lib/wire4_client/models/message_payment.rb', line 132 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } if attributes.has_key?(:'account') self.account = attributes[:'account'] end if attributes.has_key?(:'amount') self.amount = attributes[:'amount'] end if attributes.has_key?(:'beneficiary_account') self.beneficiary_account = attributes[:'beneficiary_account'] end if attributes.has_key?(:'beneficiary_bank') self.beneficiary_bank = attributes[:'beneficiary_bank'] end if attributes.has_key?(:'beneficiary_name') self.beneficiary_name = attributes[:'beneficiary_name'] end if attributes.has_key?(:'cep') self.cep = attributes[:'cep'] end if attributes.has_key?(:'clave_rastreo') self.clave_rastreo = attributes[:'clave_rastreo'] end if attributes.has_key?(:'concept') self.concept = attributes[:'concept'] end if attributes.has_key?(:'confirm_date') self.confirm_date = attributes[:'confirm_date'] end if attributes.has_key?(:'currency_code') self.currency_code = attributes[:'currency_code'] end if attributes.has_key?(:'detention_message') self. = attributes[:'detention_message'] end if attributes.has_key?(:'error_message') self. = attributes[:'error_message'] end if attributes.has_key?(:'monex_description') self.monex_description = attributes[:'monex_description'] end if attributes.has_key?(:'order_id') self.order_id = attributes[:'order_id'] end if attributes.has_key?(:'payment_order_id') self.payment_order_id = attributes[:'payment_order_id'] end if attributes.has_key?(:'pending_reason') self.pending_reason = attributes[:'pending_reason'] end if attributes.has_key?(:'reference') self.reference = attributes[:'reference'] end if attributes.has_key?(:'request_id') self.request_id = attributes[:'request_id'] end if attributes.has_key?(:'status_code') self.status_code = attributes[:'status_code'] end if attributes.has_key?(:'transaction_id') self.transaction_id = attributes[:'transaction_id'] end end |
Instance Attribute Details
#account ⇒ Object
Cuenta del ordenante
19 20 21 |
# File 'lib/wire4_client/models/message_payment.rb', line 19 def account @account end |
#amount ⇒ Object
Monto de la transferencia
22 23 24 |
# File 'lib/wire4_client/models/message_payment.rb', line 22 def amount @amount end |
#beneficiary_account ⇒ Object
Cuenta del beneficiario
25 26 27 |
# File 'lib/wire4_client/models/message_payment.rb', line 25 def beneficiary_account @beneficiary_account end |
#beneficiary_bank ⇒ Object
Banco del beneficiario
28 29 30 |
# File 'lib/wire4_client/models/message_payment.rb', line 28 def beneficiary_bank @beneficiary_bank end |
#beneficiary_name ⇒ Object
Nombre del beneficiario
31 32 33 |
# File 'lib/wire4_client/models/message_payment.rb', line 31 def beneficiary_name @beneficiary_name end |
#cep ⇒ Object
Informacion del CEP
34 35 36 |
# File 'lib/wire4_client/models/message_payment.rb', line 34 def cep @cep end |
#clave_rastreo ⇒ Object
Clave de rastreo de la transferencia
37 38 39 |
# File 'lib/wire4_client/models/message_payment.rb', line 37 def clave_rastreo @clave_rastreo end |
#concept ⇒ Object
Concepto de la transferencia de salida
40 41 42 |
# File 'lib/wire4_client/models/message_payment.rb', line 40 def concept @concept end |
#confirm_date ⇒ Object
Fecha de confirmación de la transferencia de salida
43 44 45 |
# File 'lib/wire4_client/models/message_payment.rb', line 43 def confirm_date @confirm_date end |
#currency_code ⇒ Object
Código de la moneda de la transferencia de salida
46 47 48 |
# File 'lib/wire4_client/models/message_payment.rb', line 46 def currency_code @currency_code end |
#detention_message ⇒ Object
Mensaje de detención de Monex de la transferencia de salida
49 50 51 |
# File 'lib/wire4_client/models/message_payment.rb', line 49 def end |
#error_message ⇒ Object
Mensaje de error
52 53 54 |
# File 'lib/wire4_client/models/message_payment.rb', line 52 def end |
#monex_description ⇒ Object
La descripción de Monex de la transferencia de salida
55 56 57 |
# File 'lib/wire4_client/models/message_payment.rb', line 55 def monex_description @monex_description end |
#order_id ⇒ Object
El identificador de la transferencia de salida
58 59 60 |
# File 'lib/wire4_client/models/message_payment.rb', line 58 def order_id @order_id end |
#payment_order_id ⇒ Object
El identificador de la orden de pago de Monex de la transferencia de salida
61 62 63 |
# File 'lib/wire4_client/models/message_payment.rb', line 61 def payment_order_id @payment_order_id end |
#pending_reason ⇒ Object
Razón de porque está pendiente aún cuando se autorizó la transferencia
64 65 66 |
# File 'lib/wire4_client/models/message_payment.rb', line 64 def pending_reason @pending_reason end |
#reference ⇒ Object
Referecia de la transferencia
67 68 69 |
# File 'lib/wire4_client/models/message_payment.rb', line 67 def reference @reference end |
#request_id ⇒ Object
El identificador, en esta API, de la petición de envío de la transferencia de salida
70 71 72 |
# File 'lib/wire4_client/models/message_payment.rb', line 70 def request_id @request_id end |
#status_code ⇒ Object
El estado de la transferencia de salida
73 74 75 |
# File 'lib/wire4_client/models/message_payment.rb', line 73 def status_code @status_code end |
#transaction_id ⇒ Object
El identificador de Monex de la transferencia de salida
76 77 78 |
# File 'lib/wire4_client/models/message_payment.rb', line 76 def transaction_id @transaction_id end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 |
# File 'lib/wire4_client/models/message_payment.rb', line 79 def self.attribute_map { :'account' => :'account', :'amount' => :'amount', :'beneficiary_account' => :'beneficiary_account', :'beneficiary_bank' => :'beneficiary_bank', :'beneficiary_name' => :'beneficiary_name', :'cep' => :'cep', :'clave_rastreo' => :'clave_rastreo', :'concept' => :'concept', :'confirm_date' => :'confirm_date', :'currency_code' => :'currency_code', :'detention_message' => :'detention_message', :'error_message' => :'error_message', :'monex_description' => :'monex_description', :'order_id' => :'order_id', :'payment_order_id' => :'payment_order_id', :'pending_reason' => :'pending_reason', :'reference' => :'reference', :'request_id' => :'request_id', :'status_code' => :'status_code', :'transaction_id' => :'transaction_id' } end |
.swagger_types ⇒ Object
Attribute type mapping.
105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 |
# File 'lib/wire4_client/models/message_payment.rb', line 105 def self.swagger_types { :'account' => :'String', :'amount' => :'Float', :'beneficiary_account' => :'String', :'beneficiary_bank' => :'MessageInstitution', :'beneficiary_name' => :'String', :'cep' => :'MessageCEP', :'clave_rastreo' => :'String', :'concept' => :'String', :'confirm_date' => :'DateTime', :'currency_code' => :'String', :'detention_message' => :'String', :'error_message' => :'String', :'monex_description' => :'String', :'order_id' => :'String', :'payment_order_id' => :'Integer', :'pending_reason' => :'String', :'reference' => :'Integer', :'request_id' => :'String', :'status_code' => :'String', :'transaction_id' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 |
# File 'lib/wire4_client/models/message_payment.rb', line 234 def ==(o) return true if self.equal?(o) self.class == o.class && account == o.account && amount == o.amount && beneficiary_account == o.beneficiary_account && beneficiary_bank == o.beneficiary_bank && beneficiary_name == o.beneficiary_name && cep == o.cep && clave_rastreo == o.clave_rastreo && concept == o.concept && confirm_date == o.confirm_date && currency_code == o.currency_code && == o. && == o. && monex_description == o.monex_description && order_id == o.order_id && payment_order_id == o.payment_order_id && pending_reason == o.pending_reason && reference == o.reference && request_id == o.request_id && status_code == o.status_code && transaction_id == o.transaction_id end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 |
# File 'lib/wire4_client/models/message_payment.rb', line 295 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :BOOLEAN if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model temp_model = Wire4Client.const_get(type).new temp_model.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
361 362 363 364 365 366 367 368 369 370 371 372 373 |
# File 'lib/wire4_client/models/message_payment.rb', line 361 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 |
# File 'lib/wire4_client/models/message_payment.rb', line 274 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
261 262 263 |
# File 'lib/wire4_client/models/message_payment.rb', line 261 def eql?(o) self == o end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
267 268 269 |
# File 'lib/wire4_client/models/message_payment.rb', line 267 def hash [account, amount, beneficiary_account, beneficiary_bank, beneficiary_name, cep, clave_rastreo, concept, confirm_date, currency_code, , , monex_description, order_id, payment_order_id, pending_reason, reference, request_id, status_code, transaction_id].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
221 222 223 224 |
# File 'lib/wire4_client/models/message_payment.rb', line 221 def list_invalid_properties invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
341 342 343 |
# File 'lib/wire4_client/models/message_payment.rb', line 341 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
347 348 349 350 351 352 353 354 355 |
# File 'lib/wire4_client/models/message_payment.rb', line 347 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
335 336 337 |
# File 'lib/wire4_client/models/message_payment.rb', line 335 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
228 229 230 |
# File 'lib/wire4_client/models/message_payment.rb', line 228 def valid? true end |