Class: Wire4Client::WebhooksApi

Inherits:
Object
  • Object
show all
Defined in:
lib/wire4_client/api/webhooks_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ WebhooksApi



19
20
21
# File 'lib/wire4_client/api/webhooks_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/wire4_client/api/webhooks_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#get_webhook(authorization, webhook_id, opts = {}) ⇒ WebhookResponse

Consulta de Webhook Obtiene un webhook registrado en la plataforma mediante su identificador.



28
29
30
31
# File 'lib/wire4_client/api/webhooks_api.rb', line 28

def get_webhook(authorization, webhook_id, opts = {})
  data, _status_code, _headers = get_webhook_with_http_info(authorization, webhook_id, opts)
  data
end

#get_webhook_with_http_info(authorization, webhook_id, opts = {}) ⇒ Array<(WebhookResponse, Fixnum, Hash)>

Consulta de Webhook Obtiene un webhook registrado en la plataforma mediante su identificador.



39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
# File 'lib/wire4_client/api/webhooks_api.rb', line 39

def get_webhook_with_http_info(authorization, webhook_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: WebhooksApi.get_webhook ...'
  end
  # verify the required parameter 'authorization' is set
  if @api_client.config.client_side_validation && authorization.nil?
    fail ArgumentError, "Missing the required parameter 'authorization' when calling WebhooksApi.get_webhook"
  end
  # verify the required parameter 'webhook_id' is set
  if @api_client.config.client_side_validation && webhook_id.nil?
    fail ArgumentError, "Missing the required parameter 'webhook_id' when calling WebhooksApi.get_webhook"
  end
  # resource path
  local_var_path = '/webhooks/{webhook_id}'.sub('{' + 'webhook_id' + '}', webhook_id.to_s)

  # query parameters
  query_params = {}

  # header parameters
  header_params = {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  header_params[:'Authorization'] = authorization

  # form parameters
  form_params = {}

  # http body (model)
  post_body = nil
  auth_names = []
  data, status_code, headers = @api_client.call_api(:GET, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'WebhookResponse')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: WebhooksApi#get_webhook\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_webhooks(authorization, opts = {}) ⇒ WebhooksList

Consulta la lista de Webhooks Obtiene una lista de los webhooks registrados en la plataforma que tengan el estado (estatus) Activo (ACTIVE) e Inactivo (INACTIVE).



86
87
88
89
# File 'lib/wire4_client/api/webhooks_api.rb', line 86

def get_webhooks(authorization, opts = {})
  data, _status_code, _headers = get_webhooks_with_http_info(authorization, opts)
  data
end

#get_webhooks_with_http_info(authorization, opts = {}) ⇒ Array<(WebhooksList, Fixnum, Hash)>

Consulta la lista de Webhooks Obtiene una lista de los webhooks registrados en la plataforma que tengan el estado (estatus) Activo (ACTIVE) e Inactivo (INACTIVE).



96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
# File 'lib/wire4_client/api/webhooks_api.rb', line 96

def get_webhooks_with_http_info(authorization, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: WebhooksApi.get_webhooks ...'
  end
  # verify the required parameter 'authorization' is set
  if @api_client.config.client_side_validation && authorization.nil?
    fail ArgumentError, "Missing the required parameter 'authorization' when calling WebhooksApi.get_webhooks"
  end
  # resource path
  local_var_path = '/webhooks'

  # query parameters
  query_params = {}

  # header parameters
  header_params = {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  header_params[:'Authorization'] = authorization

  # form parameters
  form_params = {}

  # http body (model)
  post_body = nil
  auth_names = []
  data, status_code, headers = @api_client.call_api(:GET, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'WebhooksList')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: WebhooksApi#get_webhooks\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#register_webhook(authorization, webhook_request, opts = {}) ⇒ WebhookResponse

Alta de Webhook Registra un webhook en la plataforma para su uso como notificador de eventos, cuándo estos ocurran.



140
141
142
143
# File 'lib/wire4_client/api/webhooks_api.rb', line 140

def register_webhook(authorization, webhook_request, opts = {})
  data, _status_code, _headers = register_webhook_with_http_info(authorization, webhook_request, opts)
  data
end

#register_webhook_with_http_info(authorization, webhook_request, opts = {}) ⇒ Array<(WebhookResponse, Fixnum, Hash)>

Alta de Webhook Registra un webhook en la plataforma para su uso como notificador de eventos, cuándo estos ocurran.



151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
# File 'lib/wire4_client/api/webhooks_api.rb', line 151

def register_webhook_with_http_info(authorization, webhook_request, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: WebhooksApi.register_webhook ...'
  end
  # verify the required parameter 'authorization' is set
  if @api_client.config.client_side_validation && authorization.nil?
    fail ArgumentError, "Missing the required parameter 'authorization' when calling WebhooksApi.register_webhook"
  end
  # verify the required parameter 'webhook_request' is set
  if @api_client.config.client_side_validation && webhook_request.nil?
    fail ArgumentError, "Missing the required parameter 'webhook_request' when calling WebhooksApi.register_webhook"
  end
  # resource path
  local_var_path = '/webhooks'

  # query parameters
  query_params = {}

  # header parameters
  header_params = {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['application/json'])
  header_params[:'Authorization'] = authorization

  # form parameters
  form_params = {}

  # http body (model)
  post_body = @api_client.object_to_http_body(webhook_request)
  auth_names = []
  data, status_code, headers = @api_client.call_api(:POST, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'WebhookResponse')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: WebhooksApi#register_webhook\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end