Class: Wire4Client::CepResponse
- Inherits:
-
Object
- Object
- Wire4Client::CepResponse
- Defined in:
- lib/wire4_client/models/cep_response.rb
Instance Attribute Summary collapse
-
#account_beneficiary ⇒ Object
Cuenta del beneficiario.
-
#account_sender ⇒ Object
Cuenta del ordenante.
-
#amount ⇒ Object
Monto de la transferencia.
-
#available ⇒ Object
Indica si o no el CEP se encuentra disponible.
-
#beneficiary_bank_key ⇒ Object
Clave del banco beneficiario.
-
#beneficiary_name ⇒ Object
Nombre del beneficiario.
-
#beneficiary_rfc ⇒ Object
RFC del beneficiario.
-
#cadena_original ⇒ Object
Cadena original del CEP.
-
#capture_date ⇒ Object
Fecha de captura de la transferencia.
-
#certificate_serial_number ⇒ Object
Número de serie del certificado.
-
#clave_rastreo ⇒ Object
Clave de rastreo.
-
#description ⇒ Object
Descripción de la transferencia.
-
#iva ⇒ Object
IVA de la transferencia.
-
#operation_date ⇒ Object
Fecha de operación de la transferencia.
-
#operation_date_cep ⇒ Object
Fecha de abono registrada en el CEP.
-
#reference ⇒ Object
Referencia numérica de la transferencia.
-
#sender_bank_key ⇒ Object
Clave del banco emisor.
-
#sender_name ⇒ Object
Nombre del emisor.
-
#sender_rfc ⇒ Object
RFC del emisor.
-
#signature ⇒ Object
Firma del CEP.
-
#url_zip ⇒ Object
La url al archivo zip del CEP, el cual contiene el xml y pdf.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CepResponse
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ CepResponse
Initializes the object
136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 |
# File 'lib/wire4_client/models/cep_response.rb', line 136 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } if attributes.has_key?(:'account_beneficiary') self.account_beneficiary = attributes[:'account_beneficiary'] end if attributes.has_key?(:'account_sender') self.account_sender = attributes[:'account_sender'] end if attributes.has_key?(:'amount') self.amount = attributes[:'amount'] end if attributes.has_key?(:'available') self.available = attributes[:'available'] end if attributes.has_key?(:'beneficiary_bank_key') self.beneficiary_bank_key = attributes[:'beneficiary_bank_key'] end if attributes.has_key?(:'beneficiary_name') self.beneficiary_name = attributes[:'beneficiary_name'] end if attributes.has_key?(:'beneficiary_rfc') self.beneficiary_rfc = attributes[:'beneficiary_rfc'] end if attributes.has_key?(:'cadena_original') self.cadena_original = attributes[:'cadena_original'] end if attributes.has_key?(:'capture_date') self.capture_date = attributes[:'capture_date'] end if attributes.has_key?(:'certificate_serial_number') self.certificate_serial_number = attributes[:'certificate_serial_number'] end if attributes.has_key?(:'clave_rastreo') self.clave_rastreo = attributes[:'clave_rastreo'] end if attributes.has_key?(:'description') self.description = attributes[:'description'] end if attributes.has_key?(:'iva') self.iva = attributes[:'iva'] end if attributes.has_key?(:'operation_date') self.operation_date = attributes[:'operation_date'] end if attributes.has_key?(:'operation_date_cep') self.operation_date_cep = attributes[:'operation_date_cep'] end if attributes.has_key?(:'reference') self.reference = attributes[:'reference'] end if attributes.has_key?(:'sender_bank_key') self.sender_bank_key = attributes[:'sender_bank_key'] end if attributes.has_key?(:'sender_name') self.sender_name = attributes[:'sender_name'] end if attributes.has_key?(:'sender_rfc') self.sender_rfc = attributes[:'sender_rfc'] end if attributes.has_key?(:'signature') self.signature = attributes[:'signature'] end if attributes.has_key?(:'url_zip') self.url_zip = attributes[:'url_zip'] end end |
Instance Attribute Details
#account_beneficiary ⇒ Object
Cuenta del beneficiario
18 19 20 |
# File 'lib/wire4_client/models/cep_response.rb', line 18 def account_beneficiary @account_beneficiary end |
#account_sender ⇒ Object
Cuenta del ordenante
21 22 23 |
# File 'lib/wire4_client/models/cep_response.rb', line 21 def account_sender @account_sender end |
#amount ⇒ Object
Monto de la transferencia
24 25 26 |
# File 'lib/wire4_client/models/cep_response.rb', line 24 def amount @amount end |
#available ⇒ Object
Indica si o no el CEP se encuentra disponible
27 28 29 |
# File 'lib/wire4_client/models/cep_response.rb', line 27 def available @available end |
#beneficiary_bank_key ⇒ Object
Clave del banco beneficiario
30 31 32 |
# File 'lib/wire4_client/models/cep_response.rb', line 30 def beneficiary_bank_key @beneficiary_bank_key end |
#beneficiary_name ⇒ Object
Nombre del beneficiario
33 34 35 |
# File 'lib/wire4_client/models/cep_response.rb', line 33 def beneficiary_name @beneficiary_name end |
#beneficiary_rfc ⇒ Object
RFC del beneficiario
36 37 38 |
# File 'lib/wire4_client/models/cep_response.rb', line 36 def beneficiary_rfc @beneficiary_rfc end |
#cadena_original ⇒ Object
Cadena original del CEP
39 40 41 |
# File 'lib/wire4_client/models/cep_response.rb', line 39 def cadena_original @cadena_original end |
#capture_date ⇒ Object
Fecha de captura de la transferencia
42 43 44 |
# File 'lib/wire4_client/models/cep_response.rb', line 42 def capture_date @capture_date end |
#certificate_serial_number ⇒ Object
Número de serie del certificado
45 46 47 |
# File 'lib/wire4_client/models/cep_response.rb', line 45 def certificate_serial_number @certificate_serial_number end |
#clave_rastreo ⇒ Object
Clave de rastreo
48 49 50 |
# File 'lib/wire4_client/models/cep_response.rb', line 48 def clave_rastreo @clave_rastreo end |
#description ⇒ Object
Descripción de la transferencia
51 52 53 |
# File 'lib/wire4_client/models/cep_response.rb', line 51 def description @description end |
#iva ⇒ Object
IVA de la transferencia
54 55 56 |
# File 'lib/wire4_client/models/cep_response.rb', line 54 def iva @iva end |
#operation_date ⇒ Object
Fecha de operación de la transferencia
57 58 59 |
# File 'lib/wire4_client/models/cep_response.rb', line 57 def operation_date @operation_date end |
#operation_date_cep ⇒ Object
Fecha de abono registrada en el CEP
60 61 62 |
# File 'lib/wire4_client/models/cep_response.rb', line 60 def operation_date_cep @operation_date_cep end |
#reference ⇒ Object
Referencia numérica de la transferencia
63 64 65 |
# File 'lib/wire4_client/models/cep_response.rb', line 63 def reference @reference end |
#sender_bank_key ⇒ Object
Clave del banco emisor
66 67 68 |
# File 'lib/wire4_client/models/cep_response.rb', line 66 def sender_bank_key @sender_bank_key end |
#sender_name ⇒ Object
Nombre del emisor
69 70 71 |
# File 'lib/wire4_client/models/cep_response.rb', line 69 def sender_name @sender_name end |
#sender_rfc ⇒ Object
RFC del emisor
72 73 74 |
# File 'lib/wire4_client/models/cep_response.rb', line 72 def sender_rfc @sender_rfc end |
#signature ⇒ Object
Firma del CEP
75 76 77 |
# File 'lib/wire4_client/models/cep_response.rb', line 75 def signature @signature end |
#url_zip ⇒ Object
La url al archivo zip del CEP, el cual contiene el xml y pdf
78 79 80 |
# File 'lib/wire4_client/models/cep_response.rb', line 78 def url_zip @url_zip end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 |
# File 'lib/wire4_client/models/cep_response.rb', line 81 def self.attribute_map { :'account_beneficiary' => :'account_beneficiary', :'account_sender' => :'account_sender', :'amount' => :'amount', :'available' => :'available', :'beneficiary_bank_key' => :'beneficiary_bank_key', :'beneficiary_name' => :'beneficiary_name', :'beneficiary_rfc' => :'beneficiary_rfc', :'cadena_original' => :'cadena_original', :'capture_date' => :'capture_date', :'certificate_serial_number' => :'certificate_serial_number', :'clave_rastreo' => :'clave_rastreo', :'description' => :'description', :'iva' => :'iva', :'operation_date' => :'operation_date', :'operation_date_cep' => :'operation_date_cep', :'reference' => :'reference', :'sender_bank_key' => :'sender_bank_key', :'sender_name' => :'sender_name', :'sender_rfc' => :'sender_rfc', :'signature' => :'signature', :'url_zip' => :'url_zip' } end |
.swagger_types ⇒ Object
Attribute type mapping.
108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 |
# File 'lib/wire4_client/models/cep_response.rb', line 108 def self.swagger_types { :'account_beneficiary' => :'String', :'account_sender' => :'String', :'amount' => :'Float', :'available' => :'BOOLEAN', :'beneficiary_bank_key' => :'String', :'beneficiary_name' => :'String', :'beneficiary_rfc' => :'String', :'cadena_original' => :'String', :'capture_date' => :'DateTime', :'certificate_serial_number' => :'String', :'clave_rastreo' => :'String', :'description' => :'String', :'iva' => :'Float', :'operation_date' => :'DateTime', :'operation_date_cep' => :'DateTime', :'reference' => :'String', :'sender_bank_key' => :'String', :'sender_name' => :'String', :'sender_rfc' => :'String', :'signature' => :'String', :'url_zip' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 |
# File 'lib/wire4_client/models/cep_response.rb', line 242 def ==(o) return true if self.equal?(o) self.class == o.class && account_beneficiary == o.account_beneficiary && account_sender == o.account_sender && amount == o.amount && available == o.available && beneficiary_bank_key == o.beneficiary_bank_key && beneficiary_name == o.beneficiary_name && beneficiary_rfc == o.beneficiary_rfc && cadena_original == o.cadena_original && capture_date == o.capture_date && certificate_serial_number == o.certificate_serial_number && clave_rastreo == o.clave_rastreo && description == o.description && iva == o.iva && operation_date == o.operation_date && operation_date_cep == o.operation_date_cep && reference == o.reference && sender_bank_key == o.sender_bank_key && sender_name == o.sender_name && sender_rfc == o.sender_rfc && signature == o.signature && url_zip == o.url_zip end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 |
# File 'lib/wire4_client/models/cep_response.rb', line 304 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :BOOLEAN if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model temp_model = Wire4Client.const_get(type).new temp_model.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
370 371 372 373 374 375 376 377 378 379 380 381 382 |
# File 'lib/wire4_client/models/cep_response.rb', line 370 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 |
# File 'lib/wire4_client/models/cep_response.rb', line 283 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
270 271 272 |
# File 'lib/wire4_client/models/cep_response.rb', line 270 def eql?(o) self == o end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
276 277 278 |
# File 'lib/wire4_client/models/cep_response.rb', line 276 def hash [account_beneficiary, account_sender, amount, available, beneficiary_bank_key, beneficiary_name, beneficiary_rfc, cadena_original, capture_date, certificate_serial_number, clave_rastreo, description, iva, operation_date, operation_date_cep, reference, sender_bank_key, sender_name, sender_rfc, signature, url_zip].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
229 230 231 232 |
# File 'lib/wire4_client/models/cep_response.rb', line 229 def list_invalid_properties invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
350 351 352 |
# File 'lib/wire4_client/models/cep_response.rb', line 350 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
356 357 358 359 360 361 362 363 364 |
# File 'lib/wire4_client/models/cep_response.rb', line 356 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
344 345 346 |
# File 'lib/wire4_client/models/cep_response.rb', line 344 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
236 237 238 |
# File 'lib/wire4_client/models/cep_response.rb', line 236 def valid? true end |