Class: Wire4Client::MessagePayment
- Inherits:
-
Object
- Object
- Wire4Client::MessagePayment
- Defined in:
- lib/wire4_client/models/message_payment.rb
Overview
El mensaje que se envía mediante (webHook) con la información del transferencia de salida realizada
Instance Attribute Summary collapse
-
#account ⇒ Object
Cuenta del ordenante.
-
#amount ⇒ Object
Monto de la transferencia.
-
#beneficiary_account ⇒ Object
Cuenta del beneficiario.
-
#beneficiary_bank ⇒ Object
Banco del beneficiario.
-
#beneficiary_name ⇒ Object
Nombre del beneficiario.
-
#cep ⇒ Object
Returns the value of attribute cep.
-
#clave_rastreo ⇒ Object
Clave de rastreo de la transferencia.
-
#concept ⇒ Object
Concepto de la transferencia de salida.
-
#confirm_date ⇒ Object
Fecha de confirmación de la transferencia de salida.
-
#currency_code ⇒ Object
Código de la moneda de la transferencia de salida.
-
#detention_message ⇒ Object
Mensaje de detención de Monex de la transferencia de salida.
-
#monex_description ⇒ Object
La descripción de Monex de la transferencia de salida.
-
#order_id ⇒ Object
El identificador de la transferencia de salida.
-
#payment_order_id ⇒ Object
El identificador de la orden de pago de Monex de la transferencia de salida.
-
#reference ⇒ Object
Referecia de la transferencia.
-
#request_id ⇒ Object
El identificador, en esta API, de la petición de envío de la transferencia de salida.
-
#status_code ⇒ Object
El estado de la transferencia de salida.
-
#transaction_id ⇒ Object
El identificador de Monex de la transferencia de salida.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ MessagePayment
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ MessagePayment
Initializes the object
121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 |
# File 'lib/wire4_client/models/message_payment.rb', line 121 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } if attributes.has_key?(:'account') self.account = attributes[:'account'] end if attributes.has_key?(:'amount') self.amount = attributes[:'amount'] end if attributes.has_key?(:'beneficiary_account') self.beneficiary_account = attributes[:'beneficiary_account'] end if attributes.has_key?(:'beneficiary_bank') self.beneficiary_bank = attributes[:'beneficiary_bank'] end if attributes.has_key?(:'beneficiary_name') self.beneficiary_name = attributes[:'beneficiary_name'] end if attributes.has_key?(:'cep') self.cep = attributes[:'cep'] end if attributes.has_key?(:'clave_rastreo') self.clave_rastreo = attributes[:'clave_rastreo'] end if attributes.has_key?(:'concept') self.concept = attributes[:'concept'] end if attributes.has_key?(:'confirm_date') self.confirm_date = attributes[:'confirm_date'] end if attributes.has_key?(:'currency_code') self.currency_code = attributes[:'currency_code'] end if attributes.has_key?(:'detention_message') self. = attributes[:'detention_message'] end if attributes.has_key?(:'monex_description') self.monex_description = attributes[:'monex_description'] end if attributes.has_key?(:'order_id') self.order_id = attributes[:'order_id'] end if attributes.has_key?(:'payment_order_id') self.payment_order_id = attributes[:'payment_order_id'] end if attributes.has_key?(:'reference') self.reference = attributes[:'reference'] end if attributes.has_key?(:'request_id') self.request_id = attributes[:'request_id'] end if attributes.has_key?(:'status_code') self.status_code = attributes[:'status_code'] end if attributes.has_key?(:'transaction_id') self.transaction_id = attributes[:'transaction_id'] end end |
Instance Attribute Details
#account ⇒ Object
Cuenta del ordenante
19 20 21 |
# File 'lib/wire4_client/models/message_payment.rb', line 19 def account @account end |
#amount ⇒ Object
Monto de la transferencia
22 23 24 |
# File 'lib/wire4_client/models/message_payment.rb', line 22 def amount @amount end |
#beneficiary_account ⇒ Object
Cuenta del beneficiario
25 26 27 |
# File 'lib/wire4_client/models/message_payment.rb', line 25 def beneficiary_account @beneficiary_account end |
#beneficiary_bank ⇒ Object
Banco del beneficiario
28 29 30 |
# File 'lib/wire4_client/models/message_payment.rb', line 28 def beneficiary_bank @beneficiary_bank end |
#beneficiary_name ⇒ Object
Nombre del beneficiario
31 32 33 |
# File 'lib/wire4_client/models/message_payment.rb', line 31 def beneficiary_name @beneficiary_name end |
#cep ⇒ Object
Returns the value of attribute cep.
33 34 35 |
# File 'lib/wire4_client/models/message_payment.rb', line 33 def cep @cep end |
#clave_rastreo ⇒ Object
Clave de rastreo de la transferencia
36 37 38 |
# File 'lib/wire4_client/models/message_payment.rb', line 36 def clave_rastreo @clave_rastreo end |
#concept ⇒ Object
Concepto de la transferencia de salida
39 40 41 |
# File 'lib/wire4_client/models/message_payment.rb', line 39 def concept @concept end |
#confirm_date ⇒ Object
Fecha de confirmación de la transferencia de salida
42 43 44 |
# File 'lib/wire4_client/models/message_payment.rb', line 42 def confirm_date @confirm_date end |
#currency_code ⇒ Object
Código de la moneda de la transferencia de salida
45 46 47 |
# File 'lib/wire4_client/models/message_payment.rb', line 45 def currency_code @currency_code end |
#detention_message ⇒ Object
Mensaje de detención de Monex de la transferencia de salida
48 49 50 |
# File 'lib/wire4_client/models/message_payment.rb', line 48 def @detention_message end |
#monex_description ⇒ Object
La descripción de Monex de la transferencia de salida
51 52 53 |
# File 'lib/wire4_client/models/message_payment.rb', line 51 def monex_description @monex_description end |
#order_id ⇒ Object
El identificador de la transferencia de salida
54 55 56 |
# File 'lib/wire4_client/models/message_payment.rb', line 54 def order_id @order_id end |
#payment_order_id ⇒ Object
El identificador de la orden de pago de Monex de la transferencia de salida
57 58 59 |
# File 'lib/wire4_client/models/message_payment.rb', line 57 def payment_order_id @payment_order_id end |
#reference ⇒ Object
Referecia de la transferencia
60 61 62 |
# File 'lib/wire4_client/models/message_payment.rb', line 60 def reference @reference end |
#request_id ⇒ Object
El identificador, en esta API, de la petición de envío de la transferencia de salida
63 64 65 |
# File 'lib/wire4_client/models/message_payment.rb', line 63 def request_id @request_id end |
#status_code ⇒ Object
El estado de la transferencia de salida
66 67 68 |
# File 'lib/wire4_client/models/message_payment.rb', line 66 def status_code @status_code end |
#transaction_id ⇒ Object
El identificador de Monex de la transferencia de salida
69 70 71 |
# File 'lib/wire4_client/models/message_payment.rb', line 69 def transaction_id @transaction_id end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 |
# File 'lib/wire4_client/models/message_payment.rb', line 72 def self.attribute_map { :'account' => :'account', :'amount' => :'amount', :'beneficiary_account' => :'beneficiary_account', :'beneficiary_bank' => :'beneficiary_bank', :'beneficiary_name' => :'beneficiary_name', :'cep' => :'cep', :'clave_rastreo' => :'clave_rastreo', :'concept' => :'concept', :'confirm_date' => :'confirm_date', :'currency_code' => :'currency_code', :'detention_message' => :'detention_message', :'monex_description' => :'monex_description', :'order_id' => :'order_id', :'payment_order_id' => :'payment_order_id', :'reference' => :'reference', :'request_id' => :'request_id', :'status_code' => :'status_code', :'transaction_id' => :'transaction_id' } end |
.swagger_types ⇒ Object
Attribute type mapping.
96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 |
# File 'lib/wire4_client/models/message_payment.rb', line 96 def self.swagger_types { :'account' => :'String', :'amount' => :'Float', :'beneficiary_account' => :'String', :'beneficiary_bank' => :'MessageInstitution', :'beneficiary_name' => :'String', :'cep' => :'MessageCEP', :'clave_rastreo' => :'String', :'concept' => :'String', :'confirm_date' => :'DateTime', :'currency_code' => :'String', :'detention_message' => :'String', :'monex_description' => :'String', :'order_id' => :'String', :'payment_order_id' => :'Integer', :'reference' => :'Integer', :'request_id' => :'String', :'status_code' => :'String', :'transaction_id' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 |
# File 'lib/wire4_client/models/message_payment.rb', line 215 def ==(o) return true if self.equal?(o) self.class == o.class && account == o.account && amount == o.amount && beneficiary_account == o.beneficiary_account && beneficiary_bank == o.beneficiary_bank && beneficiary_name == o.beneficiary_name && cep == o.cep && clave_rastreo == o.clave_rastreo && concept == o.concept && confirm_date == o.confirm_date && currency_code == o.currency_code && == o. && monex_description == o.monex_description && order_id == o.order_id && payment_order_id == o.payment_order_id && reference == o.reference && request_id == o.request_id && status_code == o.status_code && transaction_id == o.transaction_id end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 |
# File 'lib/wire4_client/models/message_payment.rb', line 274 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :BOOLEAN if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model temp_model = Wire4Client.const_get(type).new temp_model.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
340 341 342 343 344 345 346 347 348 349 350 351 352 |
# File 'lib/wire4_client/models/message_payment.rb', line 340 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 |
# File 'lib/wire4_client/models/message_payment.rb', line 253 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
240 241 242 |
# File 'lib/wire4_client/models/message_payment.rb', line 240 def eql?(o) self == o end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
246 247 248 |
# File 'lib/wire4_client/models/message_payment.rb', line 246 def hash [account, amount, beneficiary_account, beneficiary_bank, beneficiary_name, cep, clave_rastreo, concept, confirm_date, currency_code, , monex_description, order_id, payment_order_id, reference, request_id, status_code, transaction_id].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
202 203 204 205 |
# File 'lib/wire4_client/models/message_payment.rb', line 202 def list_invalid_properties invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
320 321 322 |
# File 'lib/wire4_client/models/message_payment.rb', line 320 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
326 327 328 329 330 331 332 333 334 |
# File 'lib/wire4_client/models/message_payment.rb', line 326 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
314 315 316 |
# File 'lib/wire4_client/models/message_payment.rb', line 314 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
209 210 211 |
# File 'lib/wire4_client/models/message_payment.rb', line 209 def valid? true end |