Class: Wire4Client::TransactionOutgoing
- Inherits:
-
Object
- Object
- Wire4Client::TransactionOutgoing
- Defined in:
- lib/wire4_client/models/transaction_outgoing.rb
Overview
Objeto que contiene la información de una transferencias SPEI de salida
Instance Attribute Summary collapse
-
#amount ⇒ Object
Monto de la transferencia.
-
#beneficiary_account ⇒ Object
Cuenta del beneficiario, podría ser un numero celular, TDD o Cuenta CLABE interbancaria.
-
#concept ⇒ Object
Concepto de la transferencia.
-
#currency_code ⇒ Object
Código de moneda en la que opera la cuenta.
-
#email ⇒ Object
Lista de email del beneficiario,es opcional.
-
#order_id ⇒ Object
Referencia de la transferencia asignada por el cliente.
-
#reference ⇒ Object
Referencia numérica de la transferencia.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ TransactionOutgoing
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ TransactionOutgoing
Initializes the object
67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 |
# File 'lib/wire4_client/models/transaction_outgoing.rb', line 67 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } if attributes.has_key?(:'amount') self.amount = attributes[:'amount'] end if attributes.has_key?(:'beneficiary_account') self.beneficiary_account = attributes[:'beneficiary_account'] end if attributes.has_key?(:'concept') self.concept = attributes[:'concept'] end if attributes.has_key?(:'currency_code') self.currency_code = attributes[:'currency_code'] end if attributes.has_key?(:'email') if (value = attributes[:'email']).is_a?(Array) self.email = value end end if attributes.has_key?(:'order_id') self.order_id = attributes[:'order_id'] end if attributes.has_key?(:'reference') self.reference = attributes[:'reference'] end end |
Instance Attribute Details
#amount ⇒ Object
Monto de la transferencia
19 20 21 |
# File 'lib/wire4_client/models/transaction_outgoing.rb', line 19 def amount @amount end |
#beneficiary_account ⇒ Object
Cuenta del beneficiario, podría ser un numero celular, TDD o Cuenta CLABE interbancaria
22 23 24 |
# File 'lib/wire4_client/models/transaction_outgoing.rb', line 22 def beneficiary_account @beneficiary_account end |
#concept ⇒ Object
Concepto de la transferencia
25 26 27 |
# File 'lib/wire4_client/models/transaction_outgoing.rb', line 25 def concept @concept end |
#currency_code ⇒ Object
Código de moneda en la que opera la cuenta
28 29 30 |
# File 'lib/wire4_client/models/transaction_outgoing.rb', line 28 def currency_code @currency_code end |
#email ⇒ Object
Lista de email del beneficiario,es opcional
31 32 33 |
# File 'lib/wire4_client/models/transaction_outgoing.rb', line 31 def email @email end |
#order_id ⇒ Object
Referencia de la transferencia asignada por el cliente
34 35 36 |
# File 'lib/wire4_client/models/transaction_outgoing.rb', line 34 def order_id @order_id end |
#reference ⇒ Object
Referencia numérica de la transferencia
37 38 39 |
# File 'lib/wire4_client/models/transaction_outgoing.rb', line 37 def reference @reference end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
40 41 42 43 44 45 46 47 48 49 50 |
# File 'lib/wire4_client/models/transaction_outgoing.rb', line 40 def self.attribute_map { :'amount' => :'amount', :'beneficiary_account' => :'beneficiary_account', :'concept' => :'concept', :'currency_code' => :'currency_code', :'email' => :'email', :'order_id' => :'order_id', :'reference' => :'reference' } end |
.swagger_types ⇒ Object
Attribute type mapping.
53 54 55 56 57 58 59 60 61 62 63 |
# File 'lib/wire4_client/models/transaction_outgoing.rb', line 53 def self.swagger_types { :'amount' => :'Float', :'beneficiary_account' => :'String', :'concept' => :'String', :'currency_code' => :'String', :'email' => :'Array<String>', :'order_id' => :'String', :'reference' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
252 253 254 255 256 257 258 259 260 261 262 |
# File 'lib/wire4_client/models/transaction_outgoing.rb', line 252 def ==(o) return true if self.equal?(o) self.class == o.class && amount == o.amount && beneficiary_account == o.beneficiary_account && concept == o.concept && currency_code == o.currency_code && email == o.email && order_id == o.order_id && reference == o.reference end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 |
# File 'lib/wire4_client/models/transaction_outgoing.rb', line 300 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :BOOLEAN if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model temp_model = Wire4Client.const_get(type).new temp_model.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
366 367 368 369 370 371 372 373 374 375 376 377 378 |
# File 'lib/wire4_client/models/transaction_outgoing.rb', line 366 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 |
# File 'lib/wire4_client/models/transaction_outgoing.rb', line 279 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
266 267 268 |
# File 'lib/wire4_client/models/transaction_outgoing.rb', line 266 def eql?(o) self == o end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
272 273 274 |
# File 'lib/wire4_client/models/transaction_outgoing.rb', line 272 def hash [amount, beneficiary_account, concept, currency_code, email, order_id, reference].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 |
# File 'lib/wire4_client/models/transaction_outgoing.rb', line 106 def list_invalid_properties invalid_properties = Array.new if @amount.nil? invalid_properties.push('invalid value for "amount", amount cannot be nil.') end if @amount < 0.01 invalid_properties.push('invalid value for "amount", must be greater than or equal to 0.01.') end if @beneficiary_account.nil? invalid_properties.push('invalid value for "beneficiary_account", beneficiary_account cannot be nil.') end if @concept.nil? invalid_properties.push('invalid value for "concept", concept cannot be nil.') end if @concept.to_s.length > 250 invalid_properties.push('invalid value for "concept", the character length must be smaller than or equal to 250.') end if @concept.to_s.length < 1 invalid_properties.push('invalid value for "concept", the character length must be great than or equal to 1.') end if @currency_code.nil? invalid_properties.push('invalid value for "currency_code", currency_code cannot be nil.') end if @order_id.nil? invalid_properties.push('invalid value for "order_id", order_id cannot be nil.') end if @order_id.to_s.length > 36 invalid_properties.push('invalid value for "order_id", the character length must be smaller than or equal to 36.') end if @order_id.to_s.length < 1 invalid_properties.push('invalid value for "order_id", the character length must be great than or equal to 1.') end if @reference.nil? invalid_properties.push('invalid value for "reference", reference cannot be nil.') end if @reference > 9999999 invalid_properties.push('invalid value for "reference", must be smaller than or equal to 9999999.') end if @reference < 0 invalid_properties.push('invalid value for "reference", must be greater than or equal to 0.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
346 347 348 |
# File 'lib/wire4_client/models/transaction_outgoing.rb', line 346 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
352 353 354 355 356 357 358 359 360 |
# File 'lib/wire4_client/models/transaction_outgoing.rb', line 352 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
340 341 342 |
# File 'lib/wire4_client/models/transaction_outgoing.rb', line 340 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 |
# File 'lib/wire4_client/models/transaction_outgoing.rb', line 165 def valid? return false if @amount.nil? return false if @amount < 0.01 return false if @beneficiary_account.nil? return false if @concept.nil? return false if @concept.to_s.length > 250 return false if @concept.to_s.length < 1 return false if @currency_code.nil? return false if @order_id.nil? return false if @order_id.to_s.length > 36 return false if @order_id.to_s.length < 1 return false if @reference.nil? return false if @reference > 9999999 return false if @reference < 0 true end |